@@ -86,7 +86,6 @@ static GoaProviderFeatures
 get_provider_features (GoaProvider *_provider)
 {
   return GOA_PROVIDER_FEATURE_BRANDED |
-         GOA_PROVIDER_FEATURE_CHAT |
          GOA_PROVIDER_FEATURE_PHOTOS |
          GOA_PROVIDER_FEATURE_MAPS;
 }
@@ -134,8 +133,6 @@ get_scope (GoaOAuth2Provider *provider)
   /* Note: Email is requested to obtain a human understandable unique Id  */
   return
     "user_events,"
-    "read_mailbox,"
-    "xmpp_login,"
     "email,"
     "user_photos,"
     "user_status,"
@@ -145,7 +142,7 @@ get_scope (GoaOAuth2Provider *provider)
 static guint
 get_credentials_generation (GoaProvider *provider)
 {
-  return 2;
+  return 3;
 }
 
 static const gchar *
@@ -330,10 +327,8 @@ build_object (GoaProvider         *provider,
               GError             **error)
 {
   GoaAccount *account;
-  GoaChat *chat = NULL;
   GoaPhotos *photos = NULL;
   GoaMaps *maps = NULL;
-  gboolean chat_enabled;
   gboolean photos_enabled;
   gboolean maps_enabled;
   gboolean ret = FALSE;
@@ -352,32 +347,6 @@ build_object (GoaProvider         *provider,
 
   account = goa_object_get_account (GOA_OBJECT (object));
 
-  /* Chat */
-  chat = goa_object_get_chat (GOA_OBJECT (object));
-  chat_enabled = g_key_file_get_boolean (key_file, group, "ChatEnabled", NULL);
-  if (chat_enabled)
-    {
-      if (chat == NULL)
-        {
-          chat = goa_chat_skeleton_new ();
-          goa_object_skeleton_set_chat (object, chat);
-        }
-    }
-  else
-    {
-      if (chat != NULL)
-        goa_object_skeleton_set_chat (object, NULL);
-    }
-
-  if (just_added)
-    {
-      goa_account_set_chat_disabled (account, !chat_enabled);
-      g_signal_connect (account,
-                        "notify::chat-disabled",
-                        G_CALLBACK (goa_util_account_notify_property_cb),
-                        "ChatEnabled");
-    }
-
   /* Photos */
   photos = goa_object_get_photos (GOA_OBJECT (object));
   photos_enabled = g_key_file_get_boolean (key_file, group, "PhotosEnabled", NULL);
@@ -436,7 +405,6 @@ build_object (GoaProvider         *provider,
   ret = TRUE;
 
  out:
-  g_clear_object (&chat);
   g_clear_object (&account);
   g_clear_object (&photos);
   g_clear_object (&maps);
@@ -463,11 +431,6 @@ show_account (GoaProvider         *provider,
                                                    /* Translators: This is a label for a series of
                                                     * options switches. For example: “Use for Mail”. */
                                                    _("Use for"),
-                                                   "chat-disabled",
-                                                   _("C_hat"));
-
-  goa_util_add_row_switch_from_keyfile_with_blurb (grid, row++, object,
-                                                   NULL,
                                                    "photos-disabled",
                                                    _("_Photos"));
 }
@@ -478,7 +441,6 @@ static void
 add_account_key_values (GoaOAuth2Provider *provider,
                         GVariantBuilder   *builder)
 {
-  g_variant_builder_add (builder, "{ss}", "ChatEnabled", "true");
   g_variant_builder_add (builder, "{ss}", "PhotosEnabled", "true");
   g_variant_builder_add (builder, "{ss}", "MapsEnabled", "true");
 }
